#
# spec file for package python-setuptools
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
%global flavor wheel%{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%bcond_with wheel
%else
%if "%{flavor}" == "wheel"
%define psuffix -wheel
%bcond_without wheel
%else
%define psuffix %{nil}
%bcond_with test
%bcond_with wheel
%endif
%endif
Name:           python-setuptools%{psuffix}
Version:        40.5.0
Release:        lp151.2.3.1
Summary:        Enhancements to distutils for building and distributing Python packages
License:        Python-2.0 OR ZPL-2.0
Group:          Development/Languages/Python
URL:            https://github.com/pypa/setuptools
Source:         https://files.pythonhosted.org/packages/source/s/setuptools/setuptools-%{version}.zip
Source1:        psfl.txt
Source2:        zpl.txt
BuildRequires:  %{python_module appdirs}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module xml}
BuildRequires:  %{python_module pytest}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
# needed for SLE
Requires:       python
Requires:       python-appdirs
Requires:       python-packaging
Requires:       python-six
Requires:       python-xml
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%if 0%{?suse_version} || 0%{?fedora_version} >= 24
Recommends:     ca-certificates-mozilla
%endif
# NOTE(saschpe): Distribute was merged into 0.7.x, so even though distribute
# obsoletes setuptools < 0.6.45, current setuptools obsoletes distribute again
%ifpython2
Provides:       %{oldpython}-distribute = %{version}
Obsoletes:      %{oldpython}-distribute < %{version}
%endif
%if %{with wheel}
BuildRequires:  %{python_module wheel}
%endif
%python_subpackages

%description
setuptools is a collection of enhancements to the Python distutils that
allow you to build and distribute Python packages,
especially ones that have dependencies on other packages.

%prep
%setup -q -n setuptools-%{version}
find . -type f -name "*.orig" -delete

# fix rpmlint spurious-executable-perm
chmod -x README.rst

# strip shebangs to fix rpmlint warnings
# "explain the sed":
# 1 = first line only
# s@...@...@ = same as s/.../.../ except with @ instead of /
# ^ = start; #!/ = shebang leading characters; .* = rest of line; $ = end
# replace with nothing
sed -r -i '1s@^#!/.*$@@' setuptools/command/easy_install.py

%build
%if ! %{with wheel}
%python_build
%else
%python_exec setup.py bdist_wheel --universal
%endif


%install
%if !%{with test} && !%{with wheel}
%python_install
%prepare_alternative easy_install
%fdupes %{buildroot}%{_prefix}
%endif

%if %{with wheel}
%python_expand install -D -m 0644 -t %{buildroot}%{$python_sitelib}/../wheels dist/*.whl
%endif

%check
# Test just don't work with Python 2
%if %{with test} && "%{python_flavor}" == "python3"
# the 4 skipped test rely on the bundled packages but they are
# not available on virtualenv; this is expected behaviour
export LANG=en_US.UTF-8
# tests need imports local source dir
export PYTHONPATH=$(pwd)
%pytest
%endif

%if !%{with test} && !%{with wheel}
%post
%python_install_alternative easy_install

%postun
%python_uninstall_alternative easy_install
%endif

%files %{python_files}
%if !%{with test} && !%{with wheel}
%doc CHANGES.rst README.rst
%python_alternative %{_bindir}/easy_install
%{python_sitelib}/setuptools
%{python_sitelib}/setuptools-%{version}-py%{python_version}.egg-info
%{python_sitelib}/easy_install.py*
%pycache_only %{python_sitelib}/__pycache__/easy_install.*
%dir %{python_sitelib}/pkg_resources
%{python_sitelib}/pkg_resources/*
%endif
%if %{with wheel}
%dir %{python_sitelib}/../wheels
%{python_sitelib}/../wheels/*
%endif

%changelog
* Sat Nov 14 2020 Matej Cepl <mcepl@suse.com>
- Add wheel subpackage with the generated wheel for this package
  (bsc#1176262, CVE-2019-20916).
* Tue Oct 30 2018 Arun Persaud <arun@gmx.de>
- update to version 40.5.0:
  * #1335: In pkg_resources.normalize_path, fix issue on Cygwin when
    cwd contains symlinks.
  * #1502: Deprecated support for downloads from Subversion in
    package_index/easy_install.
  * #1517: Dropped use of six.u in favor of u"" literals.
  * #1520: Added support for data_files in setup.cfg.
  * #1525: Fixed rendering of the deprecation warning in easy_install
    doc.
* Sun Sep 30 2018 Arun Persaud <arun@gmx.de>
- update to version 40.4.3:
  * #1480: Bump vendored pyparsing in pkg_resources to 2.2.1.
- changes from version 40.4.2:
  * #1497: Updated gitignore in repo.
- changes from version 40.4.1:
  * #1480: Bump vendored pyparsing to 2.2.1.
- changes from version 40.4.0:
  * #1481: Join the sdist --dist-dir and the build_meta sdist
    directory argument to point to the same target (meaning the build
    frontend no longer needs to clean manually the dist dir to avoid
    multiple sdist presence, and setuptools no longer needs to handle
    conflicts between the two).
- changes from version 40.3.0:
  * #1402: Fixed a bug with namespace packages under Python 3.6 when
    one package in current directory hides another which is
    installed.
  * #1427: Set timestamp of .egg-info directory whenever egg_info
    command is run.
  * #1474: build_meta.get_requires_for_build_sdist now does not
    include the wheel package anymore.
  * #1486: Suppress warnings in pkg_resources.handle_ns.
  * #1479: Remove internal use of six.binary_type.
* Sat Sep  1 2018 arun@gmx.de
- update to version 40.2.0:
  * #1466: Fix handling of Unicode arguments in PEP 517 backend
- changes from version 40.1.1:
  * #1465: Fix regression with egg_info command when tagging is used.
* Sat Aug 25 2018 jengelh@inai.de
- Use noun phrase in summary.
* Sat Aug 18 2018 arun@gmx.de
- specfile:
  * removed devel for noarch package
- update to version 40.1.0:
  * #1410: Deprecated upload and register commands.
  * #1312: Introduced find_namespace_packages() to find PEP 420
    namespace packages.
  * #1420: Added find_namespace: directive to config parser.
  * #1418: Solved race in when creating egg cache directories.
  * #1450: Upgraded vendored PyParsing from 2.1.10 to 2.2.0.
  * #1451: Upgraded vendored appdirs from 1.4.0 to 1.4.3.
  * #1388: Fixed "Microsoft Visual C++ Build Tools" link in exception
    when Visual C++ not found.
  * #1389: Added support for scripts which have unicode content.
  * #1416: Moved several Python version checks over to using six.PY2
    and six.PY3.
  * #1441: Removed spurious executable permissions from files that
    don't need them.
* Thu Jul 12 2018 arun@gmx.de
- update to version 40.0.0:
  * #1342: Drop support for Python 3.3.
  * #1366: In package_index, fixed handling of encoded entities in
    URLs.
  * #1383: In pkg_resources VendorImporter, avoid removing packages
    imported from the root.
  * #1379: Minor doc fixes after actually using the new release
    process.
  * #1385: Removed section on non-package data files.
  * #1403: Fix developer's guide.
  * #1404: Fix PEP 518 configuration: set build requirements in
    pyproject.toml to ["wheel"].
* Mon May 21 2018 arun@gmx.de
- update to version 39.2.0:
  * #1359: Support using "file:" to load a PEP 440-compliant package
    version from a text file.
  * #1360: Fixed issue with a mismatch between the name of the package
    and the name of the .dist-info file in wheel files
  * #1364: Add __dir__() implementation to
    pkg_resources.Distribution() that includes the attributes in the
    _provider instance variable.
  * #1365: Take the package_dir option into account when loading the
    version from a module attribute.
  * #1353: Added coverage badge to README.
  * #1356: Made small fixes to the developer guide documentation.
  * #1357: Fixed warnings in documentation builds and started
    enforcing that the docs build without warnings in tox.
  * #1376: Updated release process docs.
  * #1343: The setuptools specific long_description_content_type,
    project_urls and provides_extras fields are now set consistently
    after any distutils setup_keywords calls, allowing them to
    override values.
  * #1352: Added tox environment for documentation builds.
  * #1354: Added towncrier for changelog managment.
  * #1355: Add PR template.
  * #1368: Fixed tests which failed without network connectivity.
  * #1369: Added unit tests for PEP 425 compatibility tags support.
  * #1372: Stop testing Python 3.3 in Travis CI, now that the latest
    version of wheel no longer installs on it.
* Sun May  6 2018 arun@gmx.de
- update to version 39.1.0:
  * #1340: Update all PyPI URLs to reflect the switch to the new
    Warehouse codebase.
  * #1337: In pkg_resources, now support loading resources for modules
    loaded by the SourcelessFileLoader.
  * #1332: Silence spurious wheel related warnings on Windows.
* Mon Mar 19 2018 tchvatal@suse.com
- Version update to 39.0.1:
  * Fix utf parsing with python2
  * Various other fixes
* Sat Mar 17 2018 arun@gmx.de
- update to version 39.0.0:
  * #1296: Setuptools now vendors its own direct dependencies, no
    longer relying on the dependencies as vendored by pkg_resources.
  * #296: Removed long-deprecated support for iteration on Version
    objects as returned by pkg_resources.parse_version. Removed the
    SetuptoolsVersion and SetuptoolsLegacyVersion names as well. They
    should not have been used, but if they were, replace with Version
    and LegacyVersion from packaging.version.
- changes from version 38.7.0:
  * #1288: Add support for maintainer in PKG-INFO.
- changes from version 38.6.1:
  * #1292: Avoid generating Provides-Extra in metadata when no extra
    is present (but environment markers are).
* Sat Mar 17 2018 arun@gmx.de
- update to version 38.6.0:
  * #1286: Add support for Metadata 2.1 (PEP 566).
* Thu Mar  8 2018 arun@gmx.de
- update to version 38.5.2:
  * #1285: Fixed RuntimeError in pkg_resources.parse_requirements on
    Python 3.7 (stemming from PEP 479).
* Wed Mar  7 2018 aplanas@suse.com
- Allows Recommends and Suggest in Fedora
* Tue Feb 27 2018 aplanas@suse.com
- Recommends only for SUSE
* Tue Feb  6 2018 arun@gmx.de
- update to version 38.5.1:
  * #1271: Revert to Cython legacy build_ext behavior for
    compatibility.
- changes from version 38.5.0:
  * #1229: Expand imports in build_ext to refine detection of Cython
    availability.
  * #1270: When Cython is available, build_ext now uses the
    new_build_ext.
* Sun Feb  4 2018 arun@gmx.de
- update to version 38.4.1:
  * #1257: In bdist_egg.scan_module, fix ValueError on Python 3.7.
* Sat Jan  6 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 38.4.0:
  * #1231: Removed warning when PYTHONDONTWRITEBYTECODE is enabled.
- changes from version 38.3.0:
  * #1210: Add support for PEP 345 Project-URL metadata.
  * #1207: Add support for long_description_type to setup.cfg
    declarative config as intended and documented.
* Sun Dec 31 2017 arun@gmx.de
- update to version 38.2.5:
  * #1232: Fix trailing slash handling in pkg_resources.ZipProvider.
* Wed Dec  6 2017 arun@gmx.de
- update to version 38.2.4:
  * #1220: Fix data_files handling when installing from wheel.
* Sun Dec  3 2017 arun@gmx.de
- update to version 38.2.3:
  * fix Travis' Python 3.3 job.
- changes from version 38.2.2:
  * #1214: fix handling of namespace packages when installing from a
    wheel.
* Mon Nov 27 2017 mimi.vx@gmail.com
- update to 38.2.1
  * fix encoding handling of metadata when installing from a wheel
* Sun Nov 26 2017 arun@gmx.de
- update to version 38.2.0:
  * #1200: easy_install now support installing from wheels: they will
    be installed as standalone unzipped eggs.
- changes from version 38.1.0:
  * #1208: Improve error message when failing to locate scripts in
    egg-info metadata.
- changes from version 38.0.0:
  * #458: In order to support deterministic builds, Setuptools no
    longer allows packages to declare install_requires as unordered
    sequences (sets or dicts).
* Wed Nov 22 2017 arun@gmx.de
- update to version 37.0.0:
  * #878: Drop support for Python 2.6. Python 2.6 users should rely on
    'setuptools < 37dev'.
- changes from version 36.8.0:
  * #1190: In SSL support for package index operations, use SNI where
    available.
- changes from version 36.7.3:
  * #1175: Bug fixes to build_meta module.
* Fri Nov 17 2017 jengelh@inai.de
- Trim bias from description.
* Wed Nov 15 2017 arun@gmx.de
- specfile:
  * add missing url field
- update to version 36.7.2:
  * #701: Fixed duplicate test discovery on Python 3.
* Sat Nov 11 2017 arun@gmx.de
- update to version 36.7.1:
  * #1193: Avoid test failures in bdist_egg when
    PYTHONDONTWRITEBYTECODE is set.
- changes from version 36.7.0:
  * #1054: Support setup_requires in setup.cfg files.
- changes from version 36.6.1:
  * #1132: Removed redundant and costly serialization/parsing step in
    EntryPoint.__init__.
  * #844: bdist_egg --exclude-source-files now tested and works on
    Python 3.
* Fri Oct 13 2017 arun@gmx.de
- update to version 36.6.0:
  * #1143: Added setuptools.build_meta module, an implementation of
    PEP-517 for Setuptools-defined packages.
  * #1143: Added dist_info command for producing dist_info metadata.
* Tue Sep 19 2017 tbechtold@suse.com
- update to 36.5.0:
  * #170: When working with Mercurial checkouts, use Windows-friendly
    syntax for suppressing output.
  * Inspired by #1134, performed substantial refactoring of
    ``pkg_resources.find_on_path`` to facilitate an optimization
    for paths with many non-version entries.
  * #1075: Add new ``Description-Content-Type`` metadata field. `See here for
    documentation on how to use this field.
    <https://packaging.python.org/specifications/#description-content-type>`_
  * #1068: Sort files and directories when building eggs for
    deterministic order.
  * #196: Remove caching of easy_install command in fetch_build_egg.
    Fixes issue where ``pytest-runner-N.N`` would satisfy the installation
    of ``pytest``.
  * #1129: Fix working set dependencies handling when replacing conflicting
    distributions (e.g. when using ``setup_requires`` with a conflicting
    transitive dependency, fix #1124).
  * #1133: Improved handling of README files extensions and added
    Markdown to the list of searched READMES.
  * #1135: Improve performance of pkg_resources import by not invoking
    ``access`` or ``stat`` and using ``os.listdir`` instead.
  * #1131: Make possible using several files within ``file:`` directive
    in metadata.long_description in ``setup.cfg``.
  * fix #1105: Fix handling of requirements with environment
    markers when declared in ``setup.cfg`` (same treatment as
    for #1081).
  * #462: Don't assume a directory is an egg by the ``.egg``
    extension alone.
  * #1093: Fix test command handler with extras_require.
  * #1112, #1091, #1115: Now using Trusty containers in
    Travis for CI and CD.
  * #1092: ``pkg_resources`` now uses ``inspect.getmro`` to
    resolve classes in method resolution order.
  * #1102: Restore behavior for empty extras.
* Mon Jul 24 2017 michael@stroeder.com
- update to 36.2.2
  v36.2.2
-------
  * #1099: Revert commit a3ec721, restoring intended purpose of
  extras as part of a requirement declaration.
  v36.2.1
-------
  * fix #1086
  * fix #1087
  * support extras specifiers in install_requires requirements
  v36.2.0
-------
  * #1081: Environment markers indicated in ``install_requires``
  are now processed and treated as nameless ``extras_require``
  with markers, allowing their metadata in requires.txt to be
  correctly generated.
  * #1053: Tagged commits are now released using Travis-CI
  build stages, meaning releases depend on passing tests on
  all supported Python versions (Linux) and not just the latest
  Python version.
  v36.1.1
-------
  * #1083: Correct ``py31compat.makedirs`` to correctly honor
  ``exist_ok`` parameter.
  * #1083: Also use makedirs compatibility throughout setuptools.
  v36.1.0
-------
  * #1083: Avoid race condition on directory creation in
  ``pkg_resources.ensure_directory``.
  * Removed deprecation of and restored support for
  ``upload_docs`` command for sites other than PyPI.
  Only warehouse is dropping support, but services like
  `devpi <http://doc.devpi.net/latest/>`_ continue to
  support docs built by setuptools' plugins. See
  `this comment <https://bitbucket.org/hpk42/devpi/issues/388/support-rtd-model-for-building-uploading#comment-34292423>`_
  for more context on the motivation for this change.
* Thu Jun  8 2017 dmueller@suse.com
- update to 36.0.1
  * #1042: Fix import in py27compat module that still
    referenced six directly, rather than through the externs
    module (vendored packages hook).
  * #980 and others: Once again, Setuptools vendors all
    of its dependencies. It seems to be the case that in
    the Python ecosystem, all build tools must run without
    any dependencies (build, runtime, or otherwise). At
    such a point that a mechanism exists that allows
    build tools to have dependencies, Setuptools will adopt
    it.
  * #1015: Fix test failures on Python 3.7.
  * #1024: Add workaround for Jython #2581 in monkey module.
  * #992: Revert change introduced in v34.4.1, now
    considered invalid.
  * #1016: Revert change introduced in v35.0.0 per #1014,
    referencing #436. The approach had unintended
    consequences, causing sdist installs to be missing
    files.
- remove fix-sle11-test-failure.patch: this doesn't build for
  SLE11 anymore, so no need to patch it anymore
* Thu Feb 23 2017 jmatejek@suse.com
- update to 34.2.0
  * dependencies are no longer vendored and setuptools can't bootstrap
    without them
  * drop support for python 2.6 and 3.2
  * declarative config option for setup.cfg
  * nspkg.pth files for development
  * switch to zip format for source dist
  * ensure extras are honored when building the working set
  * add support for reading dist-info metadata
  * support for PEP440 version specifiers
- added build-time and run-time dependencies to appdirs and packaging,
  ensured these packages build without setuptools
- drop upstreamed setuptools-certpath.patch
- drop unneeded setuptools-5.4.1-create-sitedir.patch
- add fdupes
- change source file to zip, add unzip dependency
* Thu Feb 16 2017 jmatejek@suse.com
- update for multipython build
* Mon Dec 12 2016 hpj@urpla.net
- make sure, that setuptools-certpath.patch is applied
  unconditionally (fixes traceback in setuptools/ssl_support.py)
* Sat Oct  8 2016 tbechtold@suse.com
- update to 28.3.0:
  * #809: In ``find_packages()``, restore support for excluding
    a parent package without excluding a child package.
  * #805: Disable ``-nspkg.pth`` behavior on Python 3.3+ where
    PEP-420 functionality is adequate. Fixes pip #1924.
  * #803: Bump certifi to 2016.9.26.
  * #733: Do not search excluded directories for packages.
    This introduced a backwards incompatible change in ``find_packages()``
    so that ``find_packages(exclude=['foo']) == []``, excluding subpackages of ``foo``.
    Previously, ``find_packages(exclude=['foo']) == ['foo.bar']``,
    even though the parent ``foo`` package was excluded.
  * #795: Bump certifi.
  * #719: Suppress decoding errors and instead log a warning
    when metadata cannot be decoded.
  * #790: In MSVC monkeypatching, explicitly patch each
    function by name in the target module instead of inferring
    the module from the function's ``__module__``. Improves
    compatibility with other packages that might have previously
    patched distutils functions (i.e. NumPy).
  * #794: In test command, add installed eggs to PYTHONPATH
    when invoking tests so that subprocesses will also have the
    dependencies available. Fixes `tox 330
    <https://github.com/tox-dev/tox/issues/330>`_.
  * #795: Update vendored pyparsing 2.1.9.
  * #520 and #513: Suppress ValueErrors in fixup_namespace_packages
    when lookup fails.
  * Nicer, more consistent interfaces for msvc monkeypatching.
  * #779 via #781: Fix circular import.
  * #778: Fix MSVC monkeypatching.
  * Introduce the (private) ``monkey`` module to encapsulate
    the distutils monkeypatching behavior.
  * Now use Warehouse by default for
    ``upload``, patching ``distutils.config.PyPIRCCommand`` to
    affect default behavior.
    Any config in .pypirc should be updated to replace
    https://pypi.python.org/pypi/
    with
    https://upload.pypi.org/legacy/
    Similarly, any passwords stored in the keyring should be
    updated to use this new value for "system".
    The ``upload_docs`` command will continue to use the python.org
    site, but the command is now deprecated. Users are urged to use
    Read The Docs instead.
  * #776: Use EXT_SUFFIX for py_limited_api renaming.
  * #774 and #775: Use LegacyVersion from packaging when
    detecting numpy versions.
  * Re-release of 26.1.0 with pytest pinned to allow for automated
    deployment and thus proper packaging environment variables,
    fixing issues with missing executable launchers.
* Wed Aug 31 2016 jmatejek@suse.com
- fix certificate handling with certifi, add support for SUSE's
  CA bundle (setuptools-certpath.patch, fixes boo#993968)
- remove shebang lines, strip executable bit from README, to silence
  the easy rpmlint warnings
* Tue Aug 30 2016 tbechtold@suse.com
- update to 26.1.1:
  * Re-release of 26.1.0 with pytest pinned to allow for automated
    deployement and thus proper packaging environment variables,
    fixing issues with missing executable launchers.
  * #763: ``pkg_resources.get_default_cache`` now defers to the
    `appdirs project <https://pypi.org/project/appdirs>`_ to
    resolve the cache directory. Adds a vendored dependency on
    appdirs to pkg_resources.
  * #748: By default, sdists are now produced in gzipped tarfile
    format by default on all platforms, adding forward compatibility
    for the same behavior in Python 3.6 (See Python #27819).
  * #459 via #736: On Windows with script launchers,
    sys.argv[0] now reflects
    the name of the entry point, consistent with the behavior in
    distlib and pip wrappers.
  * #752 via #753: When indicating ``py_limited_api`` to Extension,
    it must be passed as a keyword argument.
  * Add Extension(py_limited_api=True). When set to a truthy value,
    that extension gets a filename apropriate for code using Py_LIMITED_API.
    When used correctly this allows a single compiled extension to work on
    all future versions of CPython 3.
    The py_limited_api argument only controls the filename. To be
    compatible with multiple versions of Python 3, the C extension
    will also need to set -DPy_LIMITED_API=... and be modified to use
    only the functions in the limited API.
  * #739 Fix unquoted libpaths by fixing compatibility between
    `numpy.distutils` and `distutils._msvccompiler`
    for numpy < 1.11.2 (Fix issue #728, error also fixed in Numpy).
  * #731: Bump certifi.
  * Style updates. See #740, #741, #743, #744, #742, #747.
  * #735: include license file.
  * #612 via #730: Add a LICENSE file which needs to be provided by the terms of
  the MIT license.
  * #725: revert `library_dir_option` patch (Error is related to
    `numpy.distutils` and make errors on non Numpy users).
  * #720
  * #723: Improve patch for `library_dir_option`.
  * #717
  * #713
  * #707: Fix Python 2 compatibility for MSVC by catching errors properly.
  * #715: Fix unquoted libpaths by patching `library_dir_option`.
  * #714 and #704: Revert fix as it breaks other components
    downstream that can't handle unicode. See #709, #710,
    and #712.
  * #704: Fix errors when installing a zip sdist that contained
    files named with non-ascii characters on Windows would
    crash the install when it attempted to clean up the build.
  * #646: MSVC compatibility - catch errors properly in
    RegistryInfo.lookup.
  * #702: Prevent UnboundLocalError when initial working_set
    is empty.
  * #686: Fix issue in sys.path ordering by pkg_resources when
    rewrite technique is "raw".
  * #699: Fix typo in msvc support.
  * #609: Setuptools will now try to download a distribution from
    the next possible download location if the first download fails.
    This means you can now specify multiple links as ``dependency_links``
    and all links will be tried until a working download link is encountered.
  * #688: Fix AttributeError in setup.py when invoked not from
    the current directory.
  * Cleanup of setup.py script.
  * Fixed documentation builders by allowing setup.py
    to be imported without having bootstrapped the
    metadata.
  * More style cleanup. See #677, #678, #679, #681, #685.
  * #674: Default ``sys.path`` manipulation by easy-install.pth
    is now "raw", meaning that when writing easy-install.pth
    during any install operation, the ``sys.path`` will not be
    rewritten and will no longer give preference to easy_installed
    packages.
    To retain the old behavior when using any easy_install
    operation (including ``setup.py install`` when setuptools is
    present), set the environment variable:
    SETUPTOOLS_SYS_PATH_TECHNIQUE=rewrite
    This project hopes that that few if any environments find it
    necessary to retain the old behavior, and intends to drop
    support for it altogether in a future release. Please report
    any relevant concerns in the ticket for this change.
  * #398: Fix shebang handling on Windows in script
    headers where spaces in ``sys.executable`` would
    produce an improperly-formatted shebang header,
    introduced in 12.0 with the fix for #188.
  * #663, #670: More style updates.
  * #516: Disable ``os.link`` to avoid hard linking
    in ``sdist.make_distribution``, avoiding errors on
    systems that support hard links but not on the
    file system in which the build is occurring.
  * #667: Update Metadata-Version to 1.2 when
    ``python_requires`` is supplied.
  * #631: Add support for ``python_requires`` keyword.
  * More style updates. See #660, #661, #641.
  * #659: ``setup.py`` now will fail fast and with a helpful
    error message when the necessary metadata is missing.
  * More style updates. See #656, #635, #640,
    [#644], #650, #652, and #655.
  * Updated style in much of the codebase to match
    community expectations. See #632, #633, #634,
    [#637], #639, #638, #642, #648.
  * If MSVC++14 is needed ``setuptools.msvc`` now redirect
    user to Visual C++ Build Tools web page.
  * #625 and #626: Fixes on ``setuptools.msvc`` mainly
    for Python 2 and Linux.
  * Pull Request #174: Add more aggressive support for
    standalone Microsoft Visual C++ compilers in
    msvc9compiler patch.
    Particularly : Windows SDK 6.1 and 7.0
    (MSVC++ 9.0), Windows SDK 7.1 (MSVC++ 10.0),
    Visual C++ Build Tools 2015 (MSVC++14)
  * Renamed ``setuptools.msvc9_support`` to
    ``setuptools.msvc``.
  Re-release of v23.2.0, which was missing the intended
  commits.
  * #623: Remove used of deprecated 'U' flag when reading
    manifests.
* Mon Jul  4 2016 dev@stellardeath.org
- Update fix-sle11-test-failure.patch to new line numbers and
  indentation
* Mon Jul  4 2016 tbechtold@suse.com
- Use pypi.io for Source url
* Thu Jun 30 2016 tbechtold@suse.com
-  update to 23.1.0:
  * #619: Deprecated ``tag_svn_revision`` distribution
    option.
  * #611: Removed ARM executables for CLI and GUI script
    launchers on Windows. If this was a feature you cared
    about, please comment in the ticket.
  * #604: Removed docs building support. The project
    now relies on documentation hosted at
    https://setuptools.readthedocs.io/.
  * #604: Restore repository for upload_docs command
    to restore publishing of docs during release.
  * #589: Upload releases to pypi.io using the upload
    hostname and legacy path.
  * #589: Releases are now uploaded to pypi.io (Warehouse)
    even when releases are made on Twine via Travis.
  * #589: Releases are now uploaded to pypi.io (Warehouse).
  * #190: On Python 2, if unicode is passed for packages to
    ``build_py`` command, it will be handled just as with
    text on Python 3.
  * #598: Setuptools now lists itself first in the User-Agent
    for web requests, better following the guidelines in
    `RFC 7231
    <https://tools.ietf.org/html/rfc7231#section-5.5.3>`_.
  * Minor fixes to changelog and docs.
  * #261: Exclude directories when resolving globs in
    package_data.
  * #539: In the easy_install get_site_dirs, honor all
    paths found in ``site.getsitepackages``.
  * #572: In build_ext, now always import ``_CONFIG_VARS``
    from ``distutils`` rather than from ``sysconfig``
    to allow ``distutils.sysconfig.customize_compiler``
    configure the OS X compiler for ``-dynamiclib``.
  * Removed ez_setup.py from Setuptools sdist. The
    bootstrap script will be maintained in its own
    branch and should be generally be retrieved from
    its canonical location at
    https://bootstrap.pypa.io/ez_setup.py.
  * #553: egg_info section is now generated in a
    deterministic order, matching the order generated
    by earlier versions of Python. Except on Python 2.6,
    order is preserved when existing settings are present.
  * #556: Update to Packaging 16.7, restoring support
    for deprecated ``python_implmentation`` marker.
  * #555: Upload command now prompts for a password
    when uploading to PyPI (or other repository) if no
    password is present in .pypirc or in the keyring.
  * #548: Update certify version to 2016.2.28
  * #545: Safely handle deletion of non-zip eggs in rotate
    command.
  * Issue #544: Fix issue with extra environment marker
    processing in WorkingSet due to refactor in v20.7.0.
  * Issue #543: Re-release so that latest release doesn't
    cause déjà vu with distribute and setuptools 0.7 in
    older environments.
  * Refactored extra enviroment marker processing
    in WorkingSet.
  * Issue #533: Fixed intermittent test failures.
  * Issue #536: In msvc9_support, trap additional exceptions
    that might occur when importing
    ``distutils.msvc9compiler`` in mingw environments.
  * Issue #537: Provide better context when package
    metadata fails to decode in UTF-8.
  * Issue #523: Restored support for environment markers,
    now honoring 'extra' environment markers.
  * Issue #523: Disabled support for environment markers
    introduced in v20.5.
  * Issue #503: Restore support for PEP 345 environment
    markers by updating to Packaging 16.6.
  * New release process that relies on
    `bumpversion <https://github.com/peritus/bumpversion>`_
    and Travis CI for continuous deployment.
  * Project versioning semantics now follow
    `semver <https://semver.org>`_ precisely.
    The 'v' prefix on version numbers now also allows
    version numbers to be referenced in the changelog,
    e.g. https://pythonhosted.org/setuptools/history.html#v20-6-0.
  * BB Pull Request #185, #470: Add support for environment markers
    in requirements in install_requires, setup_requires,
    tests_require as well as adding a test for the existing
    extra_requires machinery.
  * Issue #422: Moved hosting to
    `Github <https://github.com/pypa/setuptools>`_
    from `Bitbucket <https://bitbucket.org/pypa/setuptools>`_.
    Issues have been migrated, though all issues and comments
    are attributed to bb-migration. So if you have a particular
    issue or issues to which you've been subscribed, you will
    want to "watch" the equivalent issue in Github.
    The Bitbucket project will be retained for the indefinite
    future, but Github now hosts the canonical project repository.
  * Issue #519: Remove import hook when reloading the
    ``pkg_resources`` module.
  * BB Pull Request #184: Update documentation in ``pkg_resources``
    around new ``Requirement`` implementation.
  * BB Pull Request #179: ``pkg_resources.Requirement`` objects are
    now a subclass of ``packaging.requirements.Requirement``,
    allowing any environment markers and url (if any) to be
    affiliated with the requirement
  * BB Pull Request #179: Restore use of RequirementParseError
    exception unintentionally dropped in 20.2.
* Wed Mar  9 2016 tbechtold@suse.com
- update to 20.2.2:
  * Issue #502: Correct regression in parsing of multiple
    version specifiers separated by commas and spaces.
  * Issue #499: Restore compatiblity for legacy versions
    by bumping to packaging 16.4.
  * Changelog now includes release dates and links to PEPs.
  * Pull Request #173: Replace dual PEP 345 _markerlib implementation
    and PEP 426 implementation of environment marker support from
    packaging 16.1 and PEP 508. Fixes Issue #122.
    See also Pull Request #175, Pull Request #168, and
    Pull Request #164. Additionally:
  - ``Requirement.parse`` no longer retains the order of extras.
  - ``parse_requirements`` now requires that all versions be
    PEP-440 compliant, as revealed in #499. Packages released
    with invalid local versions should be re-released using
    the proper local version syntax, e.g. ``mypkg-1.0+myorg.1``.
  * Update ``upload_docs`` command to also honor keyring
    for password resolution.
  * Added support for using passwords from keyring in the upload
    command.
  * Issue #118: Once again omit the package metadata (egg-info)
    from the list of outputs in ``--record``. This version of setuptools
    can no longer be used to upgrade pip earlier than 6.0.
  * `Off-project PR <https://github.com/jaraco/setuptools/pull/32>`_:
    For FreeBSD, also honor root certificates from ca_root_nss.
* Mon Feb  1 2016 toddrme2178@gmail.com
- update to version 19.6.2:
  * Issue #491: Correct regression incurred in 19.4 where a
    double-namespace package installed using pip would cause a
    TypeError.
- update to version 19.6.1:
  * Restore compatibility for PyPy 3 compatibility lost in 19.4.1
    addressing Issue #487.
  * "setuptools.launch" shim now loads scripts in a new namespace,
    avoiding getting relative imports from the setuptools package on
    Python 2.
- update to version 19.6:
  * Added a new entry script "setuptools.launch", implementing the
    shim found in "pip.util.setuptools_build". Use this command to
    launch distutils-only packages under setuptools in the same way
    that pip does, causing the setuptools monkeypatching of distutils
    to be invoked prior to invoking a script. Useful for debugging or
    otherwise installing a distutils-only package under setuptools
    when pip isn't available or otherwise does not expose the desired
    functionality. For example::
    $ python -m setuptools.launch setup.py develop
  * Issue #488: Fix dual manifestation of Extension class in extension
    packages installed as dependencies when Cython is present.
- update to version 19.5:
  * Issue #486: Correct TypeError when getfilesystemencoding
    returns None.
  * Issue #139: Clarified the license as MIT.
  * Pull Request #169: Removed special handling of command
    spec in scripts for Jython.
- changes from version 19.4.1:
  * Issue #487: Use direct invocation of "importlib.machinery" in
    "pkg_resources" to avoid missing detection on relevant platforms.
- update to version 19.4:
  * Issue #341: Correct error in path handling of package data files
    in "build_py" command when package is empty.
  * Distribute #323, Issue #141, Issue #207, and Pull Request #167:
    Another implementation of "pkg_resources.WorkingSet" and
    "pkg_resources.Distribution" that supports replacing an extant
    package with a new one, allowing for setup_requires dependencies
    to supersede installed packages for the session.
- update to version 19.3:
  * Issue #229: Implement new technique for readily incorporating
    dependencies conditionally from vendored copies or primary
    locations. Adds a new dependency on six.
- update to version 19.2:
  * Pull Request #163: Add get_command_list method to Distribution.
  * Pull Request #162: Add missing whitespace to multiline string
    literals.
- update to version 19.1.1:
  * Issue #476: Cast version to string (using default encoding) to
    avoid creating Unicode types on Python 2 clients.
  * Issue #477: In Powershell downloader, use explicit rendering of
    strings, rather than rely on "repr", which can be incorrect
    (especially on Python 2).
- changes from version 19.1:
  * Issue #215: The bootstrap script "ez_setup.py" now automatically
    detects the latest version of setuptools (using PyPI JSON API)
    rather than hard-coding a particular value.
  * Issue #475: Fix incorrect usage in _translate_metadata2.
- changes from version 19.0:
  * Issue #442: Use RawConfigParser for parsing .pypirc file.
    Interpolated values are no longer honored in .pypirc files.
- update to version 18.8.1:
  * Issue #440: Prevent infinite recursion when a SandboxViolation or
    other UnpickleableException occurs in a sandbox context with
    setuptools hidden. Fixes regression introduced in Setuptools 12.0.
- changes from version 18.8:
  * Deprecated ``egg_info.get_pkg_info_revision``.
  * Issue #471: Don't rely on repr for an HTML attribute value in
    package_index.
  * Issue #419: Avoid errors in FileMetadata when the metadata directory
    is broken.
  * Issue #472: Remove deprecated use of 'U' in mode parameter
    when opening files.
- update to version 18.7.1:
  * Issue #469: Refactored logic for Issue #419 fix to re-use metadata
    loading from Provider.
- update to version 18.7:
  * Update dependency on certify.
  * Pull Request #160: Improve detection of gui script in
    "easy_install._adjust_header".
  * Made "test.test_args" a non-data property; alternate fix
    for the issue reported in Pull Request #155.
  * Issue #453: In "ez_setup" bootstrap module, unload all
    "pkg_resources" modules following download.
  * Pull Request #158: Honor `PEP-488
    <https://www.python.org/dev/peps/pep-0488/>`_ when excluding
    files for namespace packages.
  * Issue #419 and Pull Request #144: Add experimental support for
    reading the version info from distutils-installed metadata rather
    than using the version in the filename.
- update to version 18.6.1:
  * Issue #464: Correct regression in invocation of superclass on
    old-style class on Python 2.
- changes from version 18.6:
  * Issue #439: When installing entry_point scripts under development,
    omit the version number of the package, allowing any version of
    the package to be used.
- update to version 18.5:
  * In preparation for dropping support for Python 3.2, a warning is now
    logged when pkg_resources is imported on Python 3.2 or earlier
    Python 3 versions.
  * `Add support for python_platform_implementation environment marker
    <https://github.com/jaraco/setuptools/pull/28>`_.
  * `Fix dictionary mutation during iteration
    <https://github.com/jaraco/setuptools/pull/29>`_.
* Thu Oct 22 2015 toddrme2178@gmail.com
- Update to 18.4
  * Test command now always invokes unittest,
    even if no test suite is supplied.
* Tue Oct  6 2015 hpj@urpla.net
- update to 18.3.2:
  * Correct another regression in setuptools.findall
    where the fix for Python #12885 was lost.
- update to 18.3.1:
  * Issue #425: Correct regression in setuptools.findall.
- update to 18.3:
  * Setuptools now allows disabling of the manipulation of the sys.path
    during the processing of the easy-install.pth file. To do so, set
    the environment variable ``SETUPTOOLS_SYS_PATH_TECHNIQUE`` to
    anything but "rewrite" (consider "raw"). During any install operation
    with manipulation disabled, setuptools packages will be appended to
    sys.path naturally.
    Future versions may change the default behavior to disable
    manipulation. If so, the default behavior can be retained by setting
    the variable to "rewrite".
  * Issue #257: ``easy_install --version`` now shows more detail
    about the installation location and Python version.
  * Refactor setuptools.findall in preparation for re-submission
    back to distutils.
* Thu Aug 20 2015 tbechtold@suse.com
- update to 18.2:
  * Issue #412: More efficient directory search in ``find_packages``.
* Tue Aug 11 2015 tbechtold@suse.com
- update to 18.1:
  * Upgrade to vendored packaging 15.3.
* Mon Jul 20 2015 dmueller@suse.com
- update to 18.0.1:
  * Issue #401: Fix failure in test suite.
  * Dropped support for builds with Pyrex. Only Cython is supported.
  * Issue #288: Detect Cython later in the build process, after
    ``setup_requires`` dependencies are resolved.
  * Issue #396: Fixed test failure on OS X.
  * Pull Request #136: Remove excessive quoting from shebang headers
    for Jython.
* Mon Jun 22 2015 tbechtold@suse.com
- update to 17.1.1:
  * Backed out unintended changes to pkg_resources, restoring removal of
    deprecated imp module
* Mon Jun  8 2015 tbechtold@suse.com
- update to 17.1:
  * Issue #380: Add support for range operators on environment
    marker evaluation.
  * Issue #378: Do not use internal importlib._bootstrap module.
  * Issue #390: Disallow console scripts with path separators in
    the name. Removes unintended functionality and brings behavior
    into parity with pip.
  * Pull Request #130: Better error messages for errors in
    parsed requirements.
  * Pull Request #133: Removed ``setuptools.tests`` from the
    installed packages.
  * Issue #373: Provisionally expose
    ``pkg_resources._initialize_master_working_set``, allowing for
    imperative re-initialization of the master working set.
* Mon Apr 27 2015 mcihar@suse.cz
- Disable testsuite as this causes build cycle
* Wed Apr 22 2015 tbechtold@suse.com
- update to 15.1:
  * Updated Packaging to 15.1 to address Packaging #28.
  * Fix ``setuptools.sandbox._execfile()`` with Python 3.1.
- Remove fix-type-error.patch . Applied upstream
* Sat Apr 11 2015 hpj@urpla.net
- openSUSE versions up to 12.2 are affected as well from:
  AssertionError: error: must supply either home or prefix/exec-prefix -- not both
  raise version check of applying fix-sle11-test-failure.patch accordingly
* Fri Mar 27 2015 tbechtold@suse.com
- update to 15.0:
  * Pull Request #126: DistributionNotFound message now lists the package or
    packages that required it. E.g.::
    pkg_resources.DistributionNotFound: The 'colorama>=0.3.1' distribution
    was not found and is required by smlib.log.
    Note that zc.buildout once dependended on the string rendering of this
    message to determine the package that was not found. This expectation
    has since been changed, but older versions of buildout may experience
    problems. See Buildout #242 for details.
  * Issue #307: Removed PEP-440 warning during parsing of versions
    in ``pkg_resources.Distribution``.
  * Issue #364: Replace deprecated usage with recommended usage of
    ``EntryPoint.load``.
  * Issue #254: When creating temporary egg cache on Unix, use mode 755
    for creating the directory to avoid the subsequent warning if
    the directory is group writable.
  * Issue #137: Update ``Distribution.hashcmp`` so that Distributions with
    None for pyversion or platform can be compared against Distributions
    defining those attributes.
  * Issue #360: Removed undesirable behavior from test runs, preventing
    write tests and installation to system site packages.
  * Pull Request #125: Add ``__ne__`` to Requirement class.
  * Various refactoring of easy_install.
  * Bootstrap script now accepts ``--to-dir`` to customize save directory or
    allow for re-use of existing repository of setuptools versions. See
    Pull Request #112 for background.
  * Issue #285: ``easy_install`` no longer will default to installing
    packages to the "user site packages" directory if it is itself installed
    there. Instead, the user must pass ``--user`` in all cases to install
    packages to the user site packages.
    This behavior now matches that of "pip install". To configure
    an environment to always install to the user site packages, consider
    using the "install-dir" and "scripts-dir" parameters to easy_install
    through an appropriate distutils config file.
  * Issue #359: Include pytest.ini in the sdist so invocation of py.test on the
    sdist honors the pytest configuration.
    Re-release of 13.0. Intermittent connectivity issues caused the release
    process to fail and PyPI uploads no longer accept files for 13.0.
  * Issue #356: Back out Pull Request #119 as it requires Setuptools 10 or later
    as the source during an upgrade.
  * Removed build_py class from setup.py. According to 892f439d216e, this
    functionality was added to support upgrades from old Distribute versions,
    0.6.5 and 0.6.6.
  * Pull Request #119: Restore writing of ``setup_requires`` to metadata
    (previously added in 8.4 and removed in 9.0).
  * Documentation is now linked using the rst.linker package.
  * Fix ``setuptools.command.easy_install.extract_wininst_cfg()``
    with Python 2.6 and 2.7.
  * Issue #354. Added documentation on building setuptools
    documentation.
  * Issue #345: Unload all modules under pkg_resources during
    ``ez_setup.use_setuptools()``.
  * Issue #336: Removed deprecation from ``ez_setup.use_setuptools``,
    as it is clearly still used by buildout's bootstrap. ``ez_setup``
    remains deprecated for use by individual packages.
  * Simplified implementation of ``ez_setup.use_setuptools``.
  * Pull Request #118: Soften warning for non-normalized versions in
    Distribution.
  * Issue #339: Correct Attribute reference in ``cant_write_to_target``.
  * Issue #336: Deprecated ``ez_setup.use_setuptools``.
  * Issue #335: Fix script header generation on Windows.
  * Fixed incorrect class attribute in ``install_scripts``. Tests would be nice.
  * Issue #331: Fixed ``install_scripts`` command on Windows systems corrupting
    the header.
  * Restore ``setuptools.command.easy_install.sys_executable`` for pbr
    compatibility. For the future, tools should construct a CommandSpec
    explicitly.
  * Issue #188: Setuptools now support multiple entities in the value for
    ``build.executable``, such that an executable of "/usr/bin/env my-python" may
    be specified. This means that systems with a specified executable whose name
    has spaces in the path must be updated to escape or quote that value.
  * Deprecated ``easy_install.ScriptWriter.get_writer``, replaced by ``.best()``
    with slightly different semantics (no force_windows flag).
  * Issue #327: Formalize and restore support for any printable character in an
    entry point name.
  * Expose ``EntryPoint.resolve`` in place of EntryPoint._load, implementing the
    simple, non-requiring load. Deprecated all uses of ``EntryPoint._load``
    except for calling with no parameters, which is just a shortcut for
    ``ep.require(); ep.resolve();``.
    Apps currently invoking ``ep.load(require=False)`` should instead do the
    following if wanting to avoid the deprecating warning::
    getattr(ep, "resolve", lambda: ep.load(require=False))()
  * Pip #2326: Report deprecation warning at stacklevel 2 for easier diagnosis.
  * Issue #281: Since Setuptools 6.1 (Issue #268), a ValueError would be raised
    in certain cases where VersionConflict was raised with two arguments, which
    occurred in ``pkg_resources.WorkingSet.find``. This release adds support
    for indicating the dependent packages while maintaining support for
    a VersionConflict when no dependent package context is known. New unit tests
    now capture the expected interface.
  * Interop #3: Upgrade to Packaging 15.0; updates to PEP 440 so that >1.7 does
    not exclude 1.7.1 but does exclude 1.7.0 and 1.7.0.post1.
  * Issue #323: Fix regression in entry point name parsing.
  * Deprecated use of EntryPoint.load(require=False). Passing a boolean to a
    function to select behavior is an anti-pattern. Instead use
    ``Entrypoint._load()``.
  * Substantial refactoring of all unit tests. Tests are now much leaner and
    re-use a lot of fixtures and contexts for better clarity of purpose.
  * Issue #320: Added a compatibility implementation of
    ``sdist._default_revctrl``
    so that systems relying on that interface do not fail (namely, Ubuntu 12.04
    and similar Debian releases).
  * Issue #319: Fixed issue installing pure distutils packages.
  * Issue #313: Removed built-in support for subversion. Projects wishing to
    retain support for subversion will need to use a third party library. The
    extant implementation is being ported to `setuptools_svn
    <https://pypi.python.org/pypi/setuptools_svn>`_.
  * Issue #315: Updated setuptools to hide its own loaded modules during
    installation of another package. This change will enable setuptools to
    upgrade (or downgrade) itself even when its own metadata and implementation
    change.
  * Prefer vendored packaging library `as recommended
    <https://github.com/jaraco/setuptools/commit/170657b68f4b92e7e1bf82f5e19a831f57
    44af67#commitcomment-9109448>`_.
  * Issue #312: Restored presence of pkg_resources API tests (doctest) to sdist.
  * Issue #314: Disabled support for ``setup_requires`` metadata to avoid issue
    where Setuptools was unable to upgrade over earlier versions.
  * Pull Request #106: Now write ``setup_requires`` metadata.
  * Issue #311: Decoupled pkg_resources from setuptools once again.
    ``pkg_resources`` is now a package instead of a module.
  * Issue #306: Suppress warnings about Version format except in select scenarios
    (such as installation).
  * Pull Request #85: Search egg-base when adding egg-info to manifest.
  * Upgrade ``packaging`` to 14.5, giving preference to "rc" as designator for
    release candidates over "c".
  * PEP-440 warnings are now raised as their own class,
    ``pkg_resources.PEP440Warning``, instead of RuntimeWarning.
  * Disabled warnings on empty versions.
  * Upgrade ``packaging`` to 14.4, fixing an error where there is a
    different result for if 2.0.5 is contained within >2.0dev and >2.0.dev even
    though normalization rules should have made them equal.
  * Issue #296: Add warning when a version is parsed as legacy. This warning will
    make it easier for developers to recognize deprecated version numbers.
  * Issue #296: Restored support for ``__hash__`` on parse_version results.
  * Issue #296: Restored support for ``__getitem__`` and sort operations on
    parse_version result.
  * Issue #296: Restore support for iteration over parse_version result, but
    deprecated that usage with a warning. Fixes failure with buildout.
  * Implement `PEP 440 <http://legacy.python.org/dev/peps/pep-0440/>`_ within
    pkg_resources and setuptools. This change
    deprecates some version numbers such that they will no longer be installable
    without using the ``===`` escape hatch. See `the changes to test_resources
    <https://bitbucket.org/pypa/setuptools/commits/dcd552da643c4448056de84c73d56da6
    d70769d5#chg-setuptools/tests/test_resources.py>`_
    for specific examples of version numbers and specifiers that are no longer
    supported. Setuptools now "vendors" the `packaging
    <https://github.com/pypa/packaging>`_ library.
  * Issue #80, Issue #209: Eggs that are downloaded for ``setup_requires``,
    ``test_requires``, etc. are now placed in a ``./.eggs`` directory instead of
    directly in the current directory. This choice of location means the files
    can be readily managed (removed, ignored). Additionally,
    later phases or invocations of setuptools will not detect the package as
    already installed and ignore it for permanent install (See #209).
    This change is indicated as backward-incompatible as installations that
    depend on the installation in the current directory will need to account for
    the new location. Systems that ignore ``*.egg`` will probably need to be
    adapted to ignore ``.eggs``. The files will need to be manually moved or
    will be retrieved again. Most use cases will require no attention.
  * Issue #268: When resolving package versions, a VersionConflict now reports
    which package previously required the conflicting version.
  * Issue #262: Fixed regression in pip install due to egg-info directories
    being omitted. Re-opens Issue #118.
  * Issue #259: Fixed regression with namespace package handling on ``single
    version, externally managed`` installs.
  * Issue #100: When building a distribution, Setuptools will no longer match
    default files using platform-dependent case sensitivity, but rather will
    only match the files if their case matches exactly. As a result, on Windows
    and other case-insensitive file systems, files with names such as
    'readme.txt' or 'README.TXT' will be omitted from the distribution and a
    warning will be issued indicating that 'README.txt' was not found. Other
    filenames affected are:
  - README.rst
  - README
  - setup.cfg
  - setup.py (or the script name)
  - test/test*.py
    Any users producing distributions with filenames that match those above
    case-insensitively, but not case-sensitively, should rename those files in
    their repository for better portability.
  * Pull Request #72: When using ``single_version_externally_managed``, the
    exclusion list now includes Python 3.2 ``__pycache__`` entries.
  * Pull Request #76 and Pull Request #78: lines in top_level.txt are now
    ordered deterministically.
  * Issue #118: The egg-info directory is now no longer included in the list
    of outputs.
  * Issue #258: Setuptools now patches distutils msvc9compiler to
    recognize the specially-packaged compiler package for easy extension module
    support on Python 2.6, 2.7, and 3.2.
  * Issue #237: ``pkg_resources`` now uses explicit detection of Python 2 vs.
    Python 3, supporting environments where builtins have been patched to make
    Python 3 look more like Python 2.
  * Issue #240: Based on real-world performance measures against 5.4, zip
    manifests are now cached in all circumstances. The
    ``PKG_RESOURCES_CACHE_ZIP_MANIFESTS`` environment variable is no longer
    relevant. The observed "memory increase" referenced in the 5.4 release
    notes and detailed in Issue #154 was likely not an increase over the status
    quo, but rather only an increase over not storing the zip info at all.
  * Issue #242: Use absolute imports in svn_utils to avoid issues if the
    installing package adds an xml module to the path.
  * Issue #239: Fix typo in 5.5 such that fix did not take.
  * Issue #239: Setuptools now includes the setup_requires directive on
    Distribution objects and validates the syntax just like install_requires
    and tests_require directives.
  * Issue #236: Corrected regression in execfile implementation for Python 2.6.
- Enable testsuite run during build. Added BuildRequires needed for that
- Refresh setuptools-5.4.1-create-sitedir.patch
- Add fix-type-error.patch: Fix error during test run
- Add fix-sle11-test-failure.patch: Fix error during test run on SLE11SP3
* Wed Jul 23 2014 sleep_walker@suse.cz
- bump to 5.4.1
  Changes between 5.4.1 and 3.6
  * Python #7776: (ssl_support) Correct usage of host for validation when
    tunneling for HTTPS.
  * Issue #154: pkg_resources will now cache the zip manifests rather than
    re-processing the same file from disk multiple times, but only if the
    environment variable PKG_RESOURCES_CACHE_ZIP_MANIFESTS is set. Clients
    that package many modules in the same zip file will see some improvement
    in startup time by enabling this feature. This feature is not enabled by
    default because it causes a substantial increase in memory usage.
  * Issue #185: Make svn tagging work on the new style SVN metadata. Thanks
    cazabon!
  * Prune revision control directories (e.g .svn) from base path as well as
    sub-directories.
  * Added a Developer Guide to the official documentation.
  * Some code refactoring and cleanup was done with no intended behavioral
    changes.
  * During install_egg_info, the generated lines for namespace package .pth
    files are now processed even during a dry run.
  * Issue #202: Implemented more robust cache invalidation for the
    ZipImporter, building on the work in Issue #168. Special thanks to Jurko
    Gospodnetic and PJE.
  * Issue #220: Restored script templates.
  * Renamed script templates to end with .tmpl now that they no longer need to
    be processed by 2to3. Fixes spurious syntax errors during build/install.
  * Issue #218: Re-release of 3.8.1 to signal that it supersedes 4.x.
  * Incidentally, script templates were updated not to include the
    triple-quote escaping.
  * Issue #213: Use legacy StringIO behavior for compatibility under pbr.
  * Issue #218: Setuptools 3.8.1 superseded 4.0.1, and 4.x was removed from
    the available versions to install.
  * Issue #210: setup.py develop now copies scripts in binary mode rather than
    text mode, matching the behavior of the install command.
  * Extend Issue #197 workaround to include all Python 3 versions prior to
  * Issue #193: Improved handling of Unicode filenames when building
    manifests.
- drop not applying patch setuptools-0.6c9-create-sitedir.patch
- introduce applying patch with the same effect setuptools-5.4.1-create-sitedir.patch
* Thu May  8 2014 toddrme2178@gmail.com
- Update to version 3.6
  * Issue #203: Honor proxy settings for Powershell downloader in the bootstrap
    routine.
- Update to version 3.5.2
  * Issue #168: More robust handling of replaced zip files and stale caches.
    Fixes ZipImportError complaining about a 'bad local header'.
- Update to version 3.5.1
  * Issue #199: Restored ``install._install`` for compatibility with earlier
    NumPy versions.
- Update to version 3.5
  * Issue #195: Follow symbolic links in find_packages (restoring behavior
    broken in 3.4).
  * Issue #197: On Python 3.1, PKG-INFO is now saved in a UTF-8 encoding instead
    of ``sys.getpreferredencoding`` to match the behavior on Python 2.6-3.4.
  * Issue #192: Preferred bootstrap location is now
    https://bootstrap.pypa.io/ez_setup.py (mirrored from former location).
* Thu Apr 17 2014 toddrme2178@gmail.com
- Update to version 3.4.4
  * Issue #184: Correct failure where find_package over-matched
    packages when directory traversal isn't short-circuited.
- Update to version 3.4.3
  * Issue #183: Really fix test command with Python 3.1.
- Update to version 3.4.2
  * Issue #183: Fix additional regression in test command on
    Python 3.1.
- Update to version 3.4.1
  * Issue #180: Fix regression in test command not caught
    by py.test-run tests.
- Update to version 3.4
  * Issue #176: Add parameter to the test command to support a
    custom test runner: --test-runner or -r.
  * Issue #177: Now assume most common invocation to install
    command on platforms/environments without stack support
    (issuing a warning). Setuptools now installs naturally on
    IronPython. Behavior on CPython should be unchanged.
- Remove %%check, which now depends on pytest and thus introduces
  a dependency loop (setuptools->pytest->py->setuptools)
* Thu Mar 20 2014 speilicke@suse.com
- Update to version 3.3:
  * Add ``include`` parameter to ``setuptools.find_packages()``.
- Changes from version 3.2:
  * Pull Request #39: Add support for C++ targets from Cython ``.pyx`` files.
  * Issue #162: Update dependency on certifi to 1.0.1.
  * Issue #164: Update dependency on wincertstore to 0.2.
* Fri Jan 31 2014 speilicke@suse.com
- Update to version 2.1:
  * Issue #129: Suppress inspection of '*.whl' files when searching for files
    in a zip-imported file.
  * Issue #131: Fix RuntimeError when constructing an egg fetcher.
- Changes from version 2.0.2:
  * Fix NameError during installation with Python implementations (e.g. Jython)
    not containing parser module.
  * Fix NameError in sdist:re_finder.
- Changes from version 2.0.1:
  * Issue #124: Fixed error in list detection in upload_docs.
- Changes from version 2.0:
  * Issue #121: Exempt lib2to3 pickled grammars from DirectorySandbox.
  * Issue #41: Dropped support for Python 2.4 and Python 2.5. Clients requiring
    setuptools for those versions of Python should use setuptools 1.x.
  * Removed setuptools.command.easy_install.HAS_USER_SITE. Clients
    expecting this boolean variable should use site.ENABLE_USER_SITE
    instead.
  * Removed pkg_resources.ImpWrapper. Clients that expected this class
    should use pkgutil.ImpImporter instead.
- Changes from version 1.4.2:
  * Issue #116: Correct TypeError when reading a local package index on Python
    3.
- Changes from version 1.4.1:
  * Issue #114: Use sys.getfilesystemencoding for decoding config in
    bdist_wininst distributions.
  * Issue #105 and Issue #113: Establish a more robust technique for
    determining the terminal encoding
- Changes from version 1.4:
  * Issue #27: easy_install will now use credentials from .pypirc if
    present for connecting to the package index.
  * Pull Request #21: Omit unwanted newlines in package_index._encode_auth
    when the username/password pair length indicates wrapping.
- Changes from version 1.3.2:
  * Issue #99: Fix filename encoding issues in SVN support.
- Changes from version 1.3.1:
  * Remove exuberant warning in SVN support when SVN is not used.
- Changes from version 1.3:
  * Address security vulnerability in SSL match_hostname check as reported in
    Python #17997.
  * Prefer backports.ssl_match_hostname
    <https://pypi.python.org/pypi/backports.ssl_match_hostname>_ for backport
    implementation if present.
  * Correct NameError in ssl_support module (socket.error).
- Changes from version 1.2:
  * Issue #26: Add support for SVN 1.7. Special thanks to Philip Thiem for the
    contribution.
  * Issue #93: Wheels are now distributed with every release. Note that as
    reported in Issue #108, as of Pip 1.4, scripts aren't installed properly
    from wheels. Therefore, if using Pip to install setuptools from a wheel,
    the easy_install command will not be available.
  * Setuptools "natural" launcher support, introduced in 1.0, is now officially
    supported.
- Changes from version 1.1.7:
  * Fixed behavior of NameError handling in 'script template (dev).py' (script
    launcher for 'develop' installs).
  * ez_setup.py now ensures partial downloads are cleaned up following
    a failed download.
  * Distribute #363 and Issue #55: Skip an sdist test that fails on locales
    other than UTF-8.
- New dependency on python-xml
- Fix update-alternatives usage
* Fri Nov  8 2013 aj@ajaissle.de
- New upstream version
  * Fixed behavior of NameError handling in 'script template (dev).py' (script launcher for 'develop' installs).
  * ez_setup.py now ensures partial downloads are cleaned up following a failed download.
  * Distribute #363 and Issue #55: Skip an sdist test that fails on locales other than UTF-8.
* Fri Oct 11 2013 speilicke@suse.com
- Update to version 1.1.6:
  + Distribute #349: sandbox.execfile now opens the target file in binary
    mode, thus honoring a BOM in the file when compiled.
- Changes from version 1.1.5:
  + Issue #69: Second attempt at fix (logic was reversed).
- Changes from version 1.1.4:
  + Issue #77: Fix error in upload command (Python 2.4).
- Changes from version 1.1.3:
  + Fix NameError in previous patch.
- Changes from version 1.1.2:
  + Issue #69: Correct issue where 404 errors are returned for URLs with
    fragments in them (such as #egg=).
- Changes from version 1.1.1:
  + Issue #75: Add --insecure option to ez_setup.py to accommodate
    environments where a trusted SSL connection cannot be validated.
  + Issue #76: Fix AttributeError in upload command with Python 2.4.
- Changes from version 1.1:
  + Issue #71 (Distribute #333): EasyInstall now puts less emphasis on the
    condition when a host is blocked via --allow-hosts.
  + Issue #72: Restored Python 2.4 compatibility in ez_setup.py.
- Changes from version 1.0:
  + Issue #60: On Windows, Setuptools supports deferring to another launcher,
    such as Vinay Sajip's pylauncher <https://bitbucket.org/pypa/pylauncher>_
    (included with Python 3.3) to launch console and GUI scripts and not install
    its own launcher executables. This experimental functionality is currently
    only enabled if  the SETUPTOOLS_LAUNCHER environment variable is set to
    "natural". In the future, this behavior may become default, but only after
    it has matured and seen substantial adoption. The SETUPTOOLS_LAUNCHER
    also accepts "executable" to force the default behavior of creating launcher
    executables.
  + Issue #63: Bootstrap script (ez_setup.py) now prefers Powershell, curl, or
    wget for retrieving the Setuptools tarball for improved security of the
    install. The script will still fall back to a simple urlopen on
    platforms that do not have these tools.
  + Issue #65: Deprecated the Features functionality.
  + Issue #52: In VerifyingHTTPSConn, handle a tunnelled (proxied)
    connection.
  + Backward-Incompatible Changes:
    This release includes a couple of backward-incompatible changes, but most if
    not all users will find 1.0 a drop-in replacement for 0.9.
  - Issue #50: Normalized API of environment marker support. Specifically,
    removed line number and filename from SyntaxErrors when returned from
    pkg_resources.invalid_marker. Any clients depending on the specific
    string representation of exceptions returned by that function may need to
    be updated to account for this change.
  - Issue #50: SyntaxErrors generated by pkg_resources.invalid_marker are
    normalized for cross-implementation consistency.
  - Removed --ignore-conflicts-at-my-risk and --delete-conflicting
    options to easy_install. These options have been deprecated since 0.6a11.
- Unify changes format
* Sun Aug 18 2013 toddrme2178@gmail.com
- Re-add Requires: python.  Not needed for recent releases, but a
  lot of SLE packages fail without it.
* Mon Jul 29 2013 speilicke@suse.com
- Update to version 0.9.8:
  + Issue #53: Fix NameErrors in _vcs_split_rev_from_url.
- Changes from version 0.9.7:
  + Issue #49: Correct AttributeError on PyPy where a hashlib.HASH object does
    not have a .name attribute.
  + Issue #34: Documentation now refers to bootstrap script in code repository
    referenced by bookmark.
  + Add underscore-separated keys to environment markers (markerlib).
- Changes from version 0.9.6:
  + Issue #44: Test failure on Python 2.4 when MD5 hash doesn't have a .name
    attribute.
- Changes from version 0.9.5:
  + Python #17980: Fix security vulnerability in SSL certificate validation.
- Changes from version 0.9.4:
  + Issue #43: Fix issue (introduced in 0.9.1) with version resolution when
    upgrading over other releases of Setuptools.
- Changes from version 0.9.3:
  + Issue #42: Fix new AttributeError introduced in last fix.
- Changes from version 0.9.2:
  + Issue #42: Fix regression where blank checksums would trigger an
    AttributeError.
- Changes from version 0.9.1:
  + Distribute #386: Allow other positional and keyword arguments to os.open.
  + Corrected dependency on certifi mis-referenced in 0.9.
- Changes from version 0.9:
  + package_index now validates hashes other than MD5 in download links.
- Changes from version 0.8:
  + Code base now runs on Python 2.4 - Python 3.3 without Python 2to3
    conversion.
* Thu Jul 18 2013 speilicke@suse.com
- Use update-alternatives to be parallel-installable with python3-setuptools
* Tue Jun 25 2013 speilicke@suse.com
- Update to version 0.7.4:
  + Issue #20: Fix comparison of parsed SVN version on Python 3.
- Changes from version 0.7.3:
  + Issue #1: Disable installation of Windows-specific files on non-Windows systems.
  + Use new sysconfig module with Python 2.7 or >=3.2.
- Changes from version 0.7.2:
  + Issue #14: Use markerlib when the parser module is not available.
  + Issue #10: ez_setup.py now uses HTTPS to download setuptools from PyPI.
- Changes from version 0.7.1:
  + Fix NameError (Issue #3) again - broken in bad merge.
- Changes from version 0.7:
  + Merged Setuptools and Distribute. See docs/merge.txt for details.
  + Index URL now defaults to HTTPS.
  + Added experimental environment marker support. Now clients may designate a
    PEP-426 environment marker for "extra" dependencies. Setuptools uses this
    feature in setup.py for optional SSL and certificate validation support
    on older platforms. Based on Distutils-SIG discussions, the syntax is
    somewhat tentative. There should probably be a PEP with a firmer spec before
    the feature should be considered suitable for use.
  + Added support for SSL certificate validation when installing packages from
    an HTTPS service.
- Use upstream URL, SDPX style licenses
- Provide/obsolete python-distribute, which merged into setuptools-0.7.x
* Sat Dec 11 2010 saschpe@gmx.de
- re-generated spec file with py2pack based on old spec file:
  + now builds on Fedora and Mandriva
* Wed Sep  1 2010 jmatejek@novell.com
- update to dev snapshot 0.6c12 - RPM version is set
  to 0.6c11.99.r84273 so that version 0.6c12 will be an upgrade when
  it comes
- this should fix "AttributeError: 'NoneType' object has no attribute 'clone'"
  errors with python 2.7
* Tue Jan 12 2010 alexandre@exatati.com.br
- Removed obsolete python-setuptools-distutils-log.diff from sources.
* Tue Nov 10 2009 alexandre@exatati.com.br
- update to version 0.6c11
  + Fix "bdist_wininst upload" trying to upload same file twice
- additional changes from 0.6c10
  + Fix for the Python 2.6.3 build_ext API change
  + Ensure C libraries (as opposed to extensions) are also built when doing bdist_egg
  + Support for SVN 1.6
* Wed Nov  4 2009 matejcik@suse.cz
- removed obsolete python-setuptools-distutils-log patch
* Wed Aug 12 2009 matejcik@suse.cz
- improved noarch selection macro
* Fri Jul 31 2009 matejcik@suse.cz
- added noarch for suse > 11.1
* Fri Apr  3 2009 matejcik@suse.cz
- fixed spec compatibility with older versions
* Mon Mar 30 2009 matejcik@suse.cz
- update to 0.6c9
  + python 2.6 compatibility fixes
- added patch to create install path if it doesn't exist
- removed python-devel from requires
* Wed Oct 22 2008 skh@suse.de
- add python-setuptools-distutils-log.diff:
  setuptools/command/sdist.py: import distutils.log [bnc#428177]
- add python-setuptools-svn15.diff:
  setuptools/command/egg_info.py: recognize svn format version 1.5 magic
  number [also bnc#428177]
* Mon Aug 18 2008 cthiel@suse.de
- update to version 0.6c8
  + Prevent --help-commands and other junk from showing under Python 2.5
    when running easy_install --help.
  + Fixed GUI scripts sometimes not executing on Windows
  + Fixed not picking up dependency links from recursive dependencies.
  + Only make .py, .dll and .so files executable when unpacking
    eggs
  + Changes for Jython compatibility
- changes in version 0.6c7
  + ftp: download URLs now work correctly.
  + The default --index-url is now http://pypi.python.org/simple, to
    use the Python Package Index's new simpler (and faster!) REST API.
* Tue Aug  7 2007 cthiel@suse.de
- update to version 0.6c6
  + EasyInstall no longer aborts the installation process if a URL it wants
    to retrieve can't be downloaded, unless the URL is an actual package
    download.  Instead, it issues a warning and tries to keep going.
  + Fixed distutils-style scripts originally built on Windows having their
    line endings doubled when installed on any platform.
  + Added --local-snapshots-ok flag, to allow building eggs from
    projects installed using setup.py develop.
  + Fixed not HTML-decoding URLs scraped from web pages
* Fri Feb 16 2007 cthiel@suse.de
- initial package (version 0.6c5)
